---
title: Orchestrating agents
sidebarTitle: Overview
---

Many hands make for light work and orchestrating workflows containing many agents is a strength of the AG2 framework.

1. **Two-agent chat**: The simplest form of conversation pattern where two agents chat back-and-forth with each other.

2. **Sequential chat**: A sequence of chats, each between two agents, chained together by a carryover mechanism (which brings the summary of the previous chat to the context of the next chat). Useful for simple sequential workflows.

3. **Group chat**: A chat with more than two agents with options on how agents are selected.

3. **Nested chat**: A mechanism to package a workflow into a single agent/chat for reuse in a workflow.


<Warning>
As of version 0.9, we have merged the experimental Swarm functionality into the core framework, creating a new way to run group (multi-agent) chats. The new group chat contains all of the functionality available in Swarm (and more) and is covered in point #3 above.

Updating to the new group chat from your Swarm code is straightforward, see [this guide](/docs/user-guide/advanced-concepts/orchestration/swarm/deprecation) on how to do it.
</Warning>
